@@ -26,7 +26,7 @@
 
 #include "filebuf.h"
 
-extern bool iovec_parse(filebuf_t *, int sep, struct iovec *, uint32_t *);
+extern uint32_t iovec_parse(filebuf_t *, unsigned char sep, struct iovec *);
 extern void iovec_shuffle(struct iovec *, uint32_t *, uint32_t);
 extern void iovec_write(int fd, struct iovec *, uint32_t);
 
